pub fn run(provider: &impl MeshBoolean) -> ConformanceReportExpand description
Run every conformance obligation against provider.
Registration should be gated on the resulting report being conformant.
pub fn run(provider: &impl MeshBoolean) -> ConformanceReportRun every conformance obligation against provider.
Registration should be gated on the resulting report being conformant.